<?php

declare(strict_types=1);

namespace Drupal\accessible_form_validation\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Accessible form validation settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'accessible_form_validation_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['accessible_form_validation.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('accessible_form_validation.settings');

    $form['default_theme_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Accessible form validation for default theme'),
      '#description' => $this->t('Uncheck this box to disable Accessible form validation functionality for the default theme.'),
      '#default_value' => $config->get('default_theme_enabled'),
    ];
    $form['default_theme_error_message_selector'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom theme error message css class selector'),
      '#description' => $this->t('Use this field to override the default selector(form-item--error-message) for the error message container. Selector should be without "."'),
      '#default_value' => $config->get('default_theme_error_message_selector'),
      '#states' => [
        'visible' => [
          ':input[name="default_theme_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['admin_theme_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Accessible form validation for admin theme'),
      '#description' => $this->t('Uncheck this box to disable Accessible form validation functionality for the admin theme.'),
      '#default_value' => $config->get('admin_theme_enabled'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('accessible_form_validation.settings')
      ->set('default_theme_enabled', $form_state->getValue('default_theme_enabled'))
      ->set('default_theme_error_message_selector', $form_state->getValue('default_theme_error_message_selector'))
      ->set('admin_theme_enabled', $form_state->getValue('admin_theme_enabled'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
